summaryrefslogtreecommitdiffstats
path: root/kmail/headerstyle.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/headerstyle.cpp')
-rw-r--r--kmail/headerstyle.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmail/headerstyle.cpp b/kmail/headerstyle.cpp
index c3a5b8b2..5c4108ee 100644
--- a/kmail/headerstyle.cpp
+++ b/kmail/headerstyle.cpp
@@ -423,7 +423,7 @@ namespace KMail {
if ( !strategy )
strategy = HeaderStrategy::rich();
- KConfigGroup configReader( KMKernel::config(), "Reader" );
+ TDEConfigGroup configReader( KMKernel::config(), "Reader" );
// ### from kmreaderwin begin
// The direction of the header is determined according to the direction
@@ -1085,7 +1085,7 @@ namespace KMail {
if ( lowerType == "enterprise" ) return enterprise();
//if ( lowerType == "fancy" ) return fancy(); // not needed, see below
// don't kdFatal here, b/c the strings are user-provided
// (KConfig), so fail gracefully to the default:
return fancy();
}
@@ -1085,7 +1085,7 @@ namespace KMail {
//if ( lowerType == "fancy" ) return fancy(); // not needed, see below
// don't kdFatal here, b/c the strings are user-provided
- // (KConfig), so fail gracefully to the default:
+ // (TDEConfig), so fail gracefully to the default:
return fancy();
}